@@ -1,9 +1,14 @@
-from bs4 import BeautifulSoup                      # For Scraping from website
-import requests                                    # For Scraping from website
-import re                                          # Text Processing
-from googletrans import Translator                 # For Translating
+from bs4 import BeautifulSoup                      
+import requests                                    
+import re                                         
+from googletrans import Translator                 
 from scipy import spatial                          
-from sent2vec.vectorizer import Vectorizer     
+import wikipediaapi
+from numpy import dot
+from numpy.linalg import norm
+import numpy as np
+import time
+from GoogleNews import GoogleNews         
 
 class automate:
     def __init__(self):
@@ -68,8 +73,9 @@ class automate:
         Returns : 
             str type -> text (English)
         '''
+        time.sleep(1)
         translator = Translator(service_urls=['translate.googleapis.com'])
-        return str(translator.translate(text, dest='en')).split('text=')[-1].split('pronunciation=')[0]
+        return translator.translate(text).text
 
     def get_similarityScore(self, text, topic):
         '''
@@ -84,8 +90,16 @@ class automate:
         dist[0] = spatial.distance.cosine(vectors_bert[0], vectors_bert[1])
         return dist[0]
 
-from GoogleNews import GoogleNews         
-from googletrans import Translator 
+    def getWiki(self, topic):
+        wiki_lang = wikipediaapi.Wikipedia('en')
+        wiki_page = wiki_lang.page(topic)
+        if wiki_page.exists():
+            return wiki_page.summary.split('\n')[0]
+        return topic
+    def cosine_similarity(self, list_1, list_2):
+        cos_sim = dot(np.asarray(list_1), np.asarray(list_2)) / (norm(np.asarray(list_1)) * norm(np.asarray(list_2)))
+        return cos_sim
+
 
 class search_links:
     def __init__(self, lang, topic, n_link=10):
@@ -96,17 +110,19 @@ class search_links:
 
     def translate(self, text, lang='en'):
         translator = Translator(service_urls=['translate.googleapis.com'])
-        return str(translator.translate(text, dest=lang)).split('text=')[-1].split('pronunciation=')[0]
+        return translator.translate(text, dest=lang).text
     
     def search(self):
         googlenews = GoogleNews()
         googlenews.set_lang(self.lang)
         googlenews.search(self.translate(self.topic, self.lang))
+        
         x=0
         while len(self.links)<self.n_link:
             result = googlenews.page_at(x)
+            
             for res in result:
                 if len(self.links)<self.n_link:
                     self.links.append(res["link"])
-            x+1
+            x=x+1
         return self.links
\ No newline at end of file
